@@ -1,24 +1,24 @@
 /*---------------------------------------------------------------------------
- 
+
   FILENAME:
         wh1080Protocol.c
- 
+
   PURPOSE:
         Provide protocol utilities for WH1080 station communication.
- 
+
   REVISION HISTORY:
         Date            Engineer        Revision        Remarks
         02/17/2011      M.S. Teel       0               Original
- 
+
   NOTES:
         Parts of this implementation were inspired by the fowsr project
         (C) Arne-Jorgen Auberg (arne.jorgen.auberg@gmail.com) with hidapi
         mods by Bill Northcott.
- 
+
   LICENSE:
-        This source code is released for free distribution under the terms 
+        This source code is released for free distribution under the terms
         of the GNU General Public License.
-  
+
 ----------------------------------------------------------------------------*/
 
 /*  ... System include files
@@ -61,7 +61,7 @@ static WH1080_WORK          wh1080Work;
 
 // Define the position, decode type, conversion factor and the storage variable
 // for the station data retrieved via USB:
-static WH1080_DECODE_TYPE   decodeVals[] = 
+static WH1080_DECODE_TYPE   decodeVals[] =
 {
     {0, ub,  1.0, &wh1080Work.sensorData.delay},        // Minutes since last stored reading (1:240)
     {1, ub,  1.0, &wh1080Work.sensorData.inhumidity},   // Indoor relative humidity % (1:99), 0xFF means invalid
@@ -78,92 +78,92 @@ static WH1080_DECODE_TYPE   decodeVals[] =
 
 // Local methods:
 
-static uint16_t getUSHORT(char* raw)
+static uint16_t getUSHORT( char* raw )
 {
-    unsigned char lo = (unsigned char)raw[0];
-    unsigned char hi = (unsigned char)raw[1];
-    return lo + (hi * 256);
+    unsigned char lo = ( unsigned char )raw[0];
+    unsigned char hi = ( unsigned char )raw[1];
+    return lo + ( hi * 256 );
 }
 
-static int16_t getSHORT(char* raw)
+static int16_t getSHORT( char* raw )
 {
-    unsigned char lo = (unsigned char)raw[0];
-    unsigned char hi = (unsigned char)raw[1];
-    uint16_t us = lo + (hi * 256);
-    if (us >= 0x8000)                       // Test for sign bit
-        return -(us - 0x8000);              // Negative value
+    unsigned char lo = ( unsigned char )raw[0];
+    unsigned char hi = ( unsigned char )raw[1];
+    uint16_t us = lo + ( hi * 256 );
+    if( us >= 0x8000 )                      // Test for sign bit
+        return -( us - 0x8000 );            // Negative value
     else
         return us;                          // Positive value
 }
 
-static uint8_t bcdDecode(uint8_t byte)
+static uint8_t bcdDecode( uint8_t byte )
 {
     uint8_t   lo = byte & 0x0F;
     uint8_t   hi = byte / 16;
 
-    return (lo + (hi * 10));
+    return ( lo + ( hi * 10 ) );
 }
 
-static int decodeSensor(char* raw, enum ws_types ws_type, float scale, float* var)
+static int decodeSensor( char* raw, enum ws_types ws_type, float scale, float* var )
 {
     float           fresult;
     uint16_t        usTemp;
 
-    switch (ws_type)
+    switch( ws_type )
     {
     case ub:
-        if ((unsigned char)raw[0] == 0xFF)
+        if( ( unsigned char )raw[0] == 0xFF )
         {
             // Deal with humidity < 10% problem by hard-coding to 9:
             fresult = 9;
         }
         else
         {
-            fresult = (unsigned char)raw[0] * scale;
+            fresult = ( unsigned char )raw[0] * scale;
         }
         break;
     case us:
-        usTemp = getUSHORT(raw);
-        if (usTemp == 0xFFFF)
+        usTemp = getUSHORT( raw );
+        if( usTemp == 0xFFFF )
         {
             return ERROR;
         }
         fresult = usTemp * scale;
         break;
     case ss:
-        if (((unsigned char)raw[0] == 0xFF) && ((unsigned char)raw[1] == 0xFF))
+        if( ( ( unsigned char )raw[0] == 0xFF ) && ( ( unsigned char )raw[1] == 0xFF ) )
         {
             return ERROR;
         }
-        fresult = getSHORT(raw) * scale;
+        fresult = getSHORT( raw ) * scale;
         break;
     case pb:
-        fresult = (unsigned char)raw[0];
+        fresult = ( unsigned char )raw[0];
         break;
     case wa:
         // wind average - 12 bits split across a byte and a nibble
-        if (((unsigned char)raw[0] == 0xFF) && (((unsigned char)raw[2] & 0x0F) == 0x0F))
+        if( ( ( unsigned char )raw[0] == 0xFF ) && ( ( ( unsigned char )raw[2] & 0x0F ) == 0x0F ) )
         {
             return ERROR;
         }
-        fresult = (unsigned char)raw[0] + (((unsigned char)raw[2] & 0x0F) * 256);
+        fresult = ( unsigned char )raw[0] + ( ( ( unsigned char )raw[2] & 0x0F ) * 256 );
         fresult = fresult * scale;
         break;
     case wg:
         // wind gust - 12 bits split across a byte and a nibble
-        if (((unsigned char)raw[0] == 0xFF) && (((unsigned char)raw[1] & 0xF0) == 0xF0))
+        if( ( ( unsigned char )raw[0] == 0xFF ) && ( ( ( unsigned char )raw[1] & 0xF0 ) == 0xF0 ) )
         {
             return ERROR;
         }
-        fresult = (unsigned char)raw[0] + (((unsigned char)raw[1] & 0xF0) * 16);
+        fresult = ( unsigned char )raw[0] + ( ( ( unsigned char )raw[1] & 0xF0 ) * 16 );
         fresult = fresult * scale;
         break;
     case wd:
-        if (((unsigned char)raw[0] & 0x80) == 0x80)
+        if( ( ( unsigned char )raw[0] & 0x80 ) == 0x80 )
         {
             return ERROR;
         }
-        fresult = (unsigned char)raw[0] * scale;
+        fresult = ( unsigned char )raw[0] * scale;
         fresult *= 22.5;
         break;
     default:
@@ -176,7 +176,7 @@ static int decodeSensor(char* raw, enum ws_types ws_type, float scale, float* va
 }
 
 // Expects the medium to already be open:
-static int readBlock (WVIEWD_WORK *work, int offset, uint8_t* buffer)
+static int readBlock( WVIEWD_WORK* work, int offset, uint8_t* buffer )
 {
     // Read 32 bytes data at offset 'offset':
     // After sending the read command, the device will send back 32 bytes data within 100ms.
@@ -187,48 +187,48 @@ static int readBlock (WVIEWD_WORK *work, int offset, uint8_t* buffer)
     int      retVal, readDone = FALSE, firstTime = TRUE;
 
     rqstBuffer[0] = 0xA1;                   // READ COMMAND
-    rqstBuffer[1] = (char)(offset / 256);   // READ ADDRESS HIGH
-    rqstBuffer[2] = (char)(offset & 0xFF);  // READ ADDRESS LOW
+    rqstBuffer[1] = ( char )( offset / 256 ); // READ ADDRESS HIGH
+    rqstBuffer[2] = ( char )( offset & 0xFF ); // READ ADDRESS LOW
     rqstBuffer[3] = 0x20;                   // END MARK
     rqstBuffer[4] = 0xA1;                   // READ COMMAND
-    rqstBuffer[5] = (char)(offset / 256);   // READ ADDRESS HIGH
-    rqstBuffer[6] = (char)(offset & 0xFF);  // READ ADDRESS LOW
+    rqstBuffer[5] = ( char )( offset / 256 ); // READ ADDRESS HIGH
+    rqstBuffer[6] = ( char )( offset & 0xFF ); // READ ADDRESS LOW
     rqstBuffer[7] = 0x20;                   // END MARK
 
     // Read any pending data on USB bus and discard before starting:
-    (*(work->medium.usbhidRead))(&work->medium, newBuffer, 32, 500);
+    ( *( work->medium.usbhidRead ) )( &work->medium, newBuffer, 32, 500 );
 
     // Read until consecutive reads produce an identical buffer:
-    while ((!work->exiting) && (!readDone))
+    while( ( !work->exiting ) && ( !readDone ) )
     {
         // Request read of 32-byte chunk from offset:
-        retVal = (*(work->medium.usbhidWrite))(&work->medium, rqstBuffer, 8);
-        if (retVal != 8)
+        retVal = ( *( work->medium.usbhidWrite ) )( &work->medium, rqstBuffer, 8 );
+        if( retVal != 8 )
         {
-            radMsgLog (PRI_HIGH, "WH1080: write data request failed!");
+            radMsgLog( PRI_HIGH, "WH1080: write data request failed!" );
             return ERROR;
         }
-    
+
         // Read 32-byte chunk and place in buffer:
-        retVal = (*(work->medium.usbhidRead))(&work->medium, newBuffer, 32, 1000);
-        if (retVal != 32)
+        retVal = ( *( work->medium.usbhidRead ) )( &work->medium, newBuffer, 32, 1000 );
+        if( retVal != 32 )
         {
-            radMsgLog (PRI_HIGH, "WH1080: read data block failed!");
+            radMsgLog( PRI_HIGH, "WH1080: read data block failed!" );
             return ERROR;
         }
 
         // Compare to previous result:
-        if (!firstTime)
+        if( !firstTime )
         {
-            if (memcmp(oldBuffer, newBuffer, 32) == 0)
+            if( memcmp( oldBuffer, newBuffer, 32 ) == 0 )
             {
                 // They match and we are done:
-                memcpy(buffer, newBuffer, 32);
+                memcpy( buffer, newBuffer, 32 );
                 readDone = TRUE;
             }
             else
             {
-                radMsgLog (PRI_STATUS, "WH1080: readBlock buffer still changing");
+                radMsgLog( PRI_STATUS, "WH1080: readBlock buffer still changing" );
             }
         }
         else
@@ -236,14 +236,14 @@ static int readBlock (WVIEWD_WORK *work, int offset, uint8_t* buffer)
             firstTime = FALSE;
         }
 
-        memcpy(oldBuffer, newBuffer, 32);
+        memcpy( oldBuffer, newBuffer, 32 );
     }
 
     return OK;
 }
 
 // Expects the medium to already be open:
-static int writeBlock (WVIEWD_WORK *work, int offset, uint8_t* buffer)
+static int writeBlock( WVIEWD_WORK* work, int offset, uint8_t* buffer )
 {
     // Write 32 bytes data at offset 'offset':
 
@@ -251,35 +251,35 @@ static int writeBlock (WVIEWD_WORK *work, int offset, uint8_t* buffer)
     int      retVal;
 
     rqstBuffer[0] = 0xA0;                   // WRITE COMMAND
-    rqstBuffer[1] = (char)(offset / 256);   // WRITE ADDRESS HIGH
-    rqstBuffer[2] = (char)(offset & 0xFF);  // WRITE ADDRESS LOW
+    rqstBuffer[1] = ( char )( offset / 256 ); // WRITE ADDRESS HIGH
+    rqstBuffer[2] = ( char )( offset & 0xFF ); // WRITE ADDRESS LOW
     rqstBuffer[3] = 0x20;                   // END MARK
     rqstBuffer[4] = 0xA0;                   // WRITE COMMAND
-    rqstBuffer[5] = (char)(offset / 256);   // WRITE ADDRESS HIGH
-    rqstBuffer[6] = (char)(offset & 0xFF);  // WRITE ADDRESS LOW
+    rqstBuffer[5] = ( char )( offset / 256 ); // WRITE ADDRESS HIGH
+    rqstBuffer[6] = ( char )( offset & 0xFF ); // WRITE ADDRESS LOW
     rqstBuffer[7] = 0x20;                   // END MARK
 
     // Request write of 32-byte chunk from offset:
-    retVal = (*(work->medium.usbhidWrite))(&work->medium, rqstBuffer, 8);
-    if (retVal != 8)
+    retVal = ( *( work->medium.usbhidWrite ) )( &work->medium, rqstBuffer, 8 );
+    if( retVal != 8 )
     {
-        radMsgLog (PRI_HIGH, "WH1080: write data request failed!");
+        radMsgLog( PRI_HIGH, "WH1080: write data request failed!" );
         return ERROR;
     }
 
     // Write 32-byte chunk:
-    retVal = (*(work->medium.usbhidWrite))(&work->medium, buffer, 32);
-    if (retVal != 32)
+    retVal = ( *( work->medium.usbhidWrite ) )( &work->medium, buffer, 32 );
+    if( retVal != 32 )
     {
-        radMsgLog (PRI_HIGH, "WH1080: write data block failed!");
+        radMsgLog( PRI_HIGH, "WH1080: write data block failed!" );
         return ERROR;
     }
 
     // Read 8-byte ACK:
-    retVal = (*(work->medium.usbhidRead))(&work->medium, buffer, 8, 1000);
-    if (retVal != 8)
+    retVal = ( *( work->medium.usbhidRead ) )( &work->medium, buffer, 8, 1000 );
+    if( retVal != 8 )
     {
-        radMsgLog (PRI_HIGH, "WH1080: read data ACK failed!");
+        radMsgLog( PRI_HIGH, "WH1080: read data ACK failed!" );
         return ERROR;
     }
 
@@ -287,7 +287,7 @@ static int writeBlock (WVIEWD_WORK *work, int offset, uint8_t* buffer)
 }
 
 // Expects the medium to already be open:
-static int writeDataRefresh (WVIEWD_WORK *work)
+static int writeDataRefresh( WVIEWD_WORK* work )
 {
     uint8_t  rqstBuffer[8], readBuffer[8];
     int      retVal;
@@ -301,18 +301,18 @@ static int writeDataRefresh (WVIEWD_WORK *work)
     rqstBuffer[6] = 0;
     rqstBuffer[7] = 0x20;
 
-    retVal = (*(work->medium.usbhidWrite))(&work->medium, rqstBuffer, 8);
-    if (retVal != 8)
+    retVal = ( *( work->medium.usbhidWrite ) )( &work->medium, rqstBuffer, 8 );
+    if( retVal != 8 )
     {
-        radMsgLog (PRI_HIGH, "WH1080: write data ACK failed!");
+        radMsgLog( PRI_HIGH, "WH1080: write data ACK failed!" );
         return ERROR;
     }
 
     // Read 8-byte ACK:
-    retVal = (*(work->medium.usbhidRead))(&work->medium, readBuffer, 8, 1000);
-    if (retVal != 8)
+    retVal = ( *( work->medium.usbhidRead ) )( &work->medium, readBuffer, 8, 1000 );
+    if( retVal != 8 )
     {
-        radMsgLog (PRI_HIGH, "WH1080: read data ACK failed!");
+        radMsgLog( PRI_HIGH, "WH1080: read data ACK failed!" );
         return ERROR;
     }
 
@@ -320,51 +320,51 @@ static int writeDataRefresh (WVIEWD_WORK *work)
 }
 
 // Expects the medium to already be open:
-static int readFixedBlock(WVIEWD_WORK *work, uint8_t* block)
+static int readFixedBlock( WVIEWD_WORK* work, uint8_t* block )
 {
     // Read fixed block:
-    if (readBlock(work, 0, block) == ERROR)
+    if( readBlock( work, 0, block ) == ERROR )
     {
-        radMsgLog (PRI_HIGH, "WH1080: readFixedBlock readBlock failed");
+        radMsgLog( PRI_HIGH, "WH1080: readFixedBlock readBlock failed" );
         return ERROR;
     }
 
     // Check for valid magic numbers:
-    // This is hardly an exhaustive list and I can find no definitive 
+    // This is hardly an exhaustive list and I can find no definitive
     // documentation that lists all possible values; further, I suspect it is
     // more of a header than a magic number...
-    if ((block[0] == 0x55) ||
-        (block[0] == 0xFF) ||
-        (block[0] == 0x01) ||
-        ((block[0] == 0x00) && (block[1] == 0x1E)) ||
-        ((block[0] == 0x00) && (block[1] == 0x01)))
+    if( ( block[0] == 0x55 ) ||
+            ( block[0] == 0xFF ) ||
+            ( block[0] == 0x01 ) ||
+            ( ( block[0] == 0x00 ) && ( block[1] == 0x1E ) ) ||
+            ( ( block[0] == 0x00 ) && ( block[1] == 0x01 ) ) )
     {
         return OK;
     }
     else
     {
-        radMsgLog (PRI_HIGH, "WH1080: readFixedBlock bad magic number %2.2X %2.2X",
-                   (int)block[0], (int)block[1]);
-        radMsgLog(PRI_HIGH, 
-                  "WH1080: You may want to clear the memory on the station "
-                  "console to remove any invalid records or data...");
+        radMsgLog( PRI_HIGH, "WH1080: readFixedBlock bad magic number %2.2X %2.2X",
+                   ( int )block[0], ( int )block[1] );
+        radMsgLog( PRI_HIGH,
+                   "WH1080: You may want to clear the memory on the station "
+                   "console to remove any invalid records or data..." );
         return ERROR_ABORT;
     }
 }
 
 // Expects the medium to already be open:
-static int writeFixedBlock(WVIEWD_WORK *work, uint8_t* block)
+static int writeFixedBlock( WVIEWD_WORK* work, uint8_t* block )
 {
     // Set for valid data:
     block[0] = 0x55;
     block[1] = 0xAA;
 
-    if (writeBlock(work, 0, block) == ERROR)
+    if( writeBlock( work, 0, block ) == ERROR )
     {
         return ERROR;
     }
 
-    if (writeDataRefresh(work) == ERROR)
+    if( writeDataRefresh( work ) == ERROR )
     {
         return ERROR;
     }
@@ -375,72 +375,72 @@ static int writeFixedBlock(WVIEWD_WORK *work, uint8_t* block)
 // Returns:
 // OK - if new record retrieved
 // ERROR - if there was an interface error
-// ERROR_ABORT - if there is no new record (WH1080 generates new records at 
+// ERROR_ABORT - if there is no new record (WH1080 generates new records at
 //               best once a minute)
-static int readStationData (WVIEWD_WORK *work)
+static int readStationData( WVIEWD_WORK* work )
 {
-    WH1080_IF_DATA*     ifWorkData = (WH1080_IF_DATA*)work->stationData;
+    WH1080_IF_DATA*     ifWorkData = ( WH1080_IF_DATA* )work->stationData;
     int                 currentPosition, readPosition, index, retVal;
 
-    if ((*(work->medium.usbhidInit))(&work->medium) != OK)
+    if( ( *( work->medium.usbhidInit ) )( &work->medium ) != OK )
     {
         return ERROR;
     }
 
     // Read the WH1080 fixed block:
-    retVal = readFixedBlock(work, &wh1080Work.controlBlock[0]);
-    if (retVal == ERROR_ABORT)
+    retVal = readFixedBlock( work, &wh1080Work.controlBlock[0] );
+    if( retVal == ERROR_ABORT )
     {
         // Try again later (bad magic number):
-        (*(work->medium.usbhidExit))(&work->medium);
+        ( *( work->medium.usbhidExit ) )( &work->medium );
         return ERROR_ABORT;
     }
-    else if (retVal == ERROR)
+    else if( retVal == ERROR )
     {
         // USB interface error:
-        (*(work->medium.usbhidExit))(&work->medium);
+        ( *( work->medium.usbhidExit ) )( &work->medium );
         return ERROR;
     }
 
-    // Get the current record position; the WH1080 reports the record it is 
+    // Get the current record position; the WH1080 reports the record it is
     // building, thus if it changes we need the prior just finished record:
-    currentPosition = (int)getUSHORT(&wh1080Work.controlBlock[WH1080_CURRENT_POS]);
+    currentPosition = ( int )getUSHORT( (char *)&wh1080Work.controlBlock[WH1080_CURRENT_POS] );
 
     // Make sure the index is aligned on 16-byte boundary:
-    if ((currentPosition % 16) != 0)
+    if( ( currentPosition % 16 ) != 0 )
     {
         // bogus, try again later:
-        (*(work->medium.usbhidExit))(&work->medium);
+        ( *( work->medium.usbhidExit ) )( &work->medium );
         return ERROR_ABORT;
     }
 
     // Is this the first time?
-    if (wh1080Work.lastRecord == -1)
+    if( wh1080Work.lastRecord == -1 )
     {
         // Yes.
         wh1080Work.lastRecord = currentPosition;
-        (*(work->medium.usbhidExit))(&work->medium);
+        ( *( work->medium.usbhidExit ) )( &work->medium );
         return ERROR_ABORT;
     }
 
     // Is there a new record?
-    if (currentPosition == wh1080Work.lastRecord)
+    if( currentPosition == wh1080Work.lastRecord )
     {
         // No, wait till it is finished.
-        (*(work->medium.usbhidExit))(&work->medium);
+        ( *( work->medium.usbhidExit ) )( &work->medium );
         return ERROR_ABORT;
     }
 
     // Read last record that is now complete:
-    if (readBlock(work, wh1080Work.lastRecord, &wh1080Work.recordBlock[0]) == ERROR)
+    if( readBlock( work, wh1080Work.lastRecord, &wh1080Work.recordBlock[0] ) == ERROR )
     {
-        radMsgLog (PRI_HIGH, "WH1080: read data block at index %d failed!",
-                   wh1080Work.lastRecord);
-        (*(work->medium.usbhidExit))(&work->medium);
+        radMsgLog( PRI_HIGH, "WH1080: read data block at index %d failed!",
+                   wh1080Work.lastRecord );
+        ( *( work->medium.usbhidExit ) )( &work->medium );
         return ERROR;
     }
 
-    (*(work->medium.usbhidExit))(&work->medium);
+    ( *( work->medium.usbhidExit ) )( &work->medium );
 
     readPosition = wh1080Work.lastRecord;
     wh1080Work.lastRecord = currentPosition;
@@ -449,110 +449,110 @@ static int readStationData (WVIEWD_WORK *work)
 
     // Is the record valid? Check for unpopulated record or no sensor data
     // received status bit:
-    if ((wh1080Work.recordBlock[WH1080_STATUS] & 0x40) != 0)
+    if( ( wh1080Work.recordBlock[WH1080_STATUS] & 0x40 ) != 0 )
     {
         // No!
-        radMsgLog (PRI_HIGH, 
+        radMsgLog( PRI_HIGH,
                    "WH1080: data block at index %d has bad status, ignoring the record",
-                   readPosition);
+                   readPosition );
         return ERROR_ABORT;
     }
 
     // Parse the data received:
-    for (index = 0; index < WH1080_NUM_SENSORS; index ++)
+    for( index = 0; index < WH1080_NUM_SENSORS; index ++ )
     {
-        if (decodeSensor(&wh1080Work.recordBlock[decodeVals[index].pos],
-                         decodeVals[index].ws_type,
-                         decodeVals[index].scale,
-                         decodeVals[index].var)
-            != OK)
+        if( decodeSensor( (char *)&wh1080Work.recordBlock[decodeVals[index].pos],
+                          decodeVals[index].ws_type,
+                          decodeVals[index].scale,
+                          decodeVals[index].var )
+                != OK )
         {
             // Bad sensor data, abort this cycle:
-            radMsgLog (PRI_HIGH, 
+            radMsgLog( PRI_HIGH,
                        "WH1080: data block at index %d has bad sensor value, ignoring the record",
-                       readPosition);
+                       readPosition );
             return ERROR_ABORT;
         }
     }
 
     // Convert to Imperial units:
-    wh1080Work.sensorData.intemp        = wvutilsConvertCToF(wh1080Work.sensorData.intemp);
-    wh1080Work.sensorData.outtemp       = wvutilsConvertCToF(wh1080Work.sensorData.outtemp);
-    wh1080Work.sensorData.pressure      = wvutilsConvertHPAToINHG(wh1080Work.sensorData.pressure);
-    wh1080Work.sensorData.windAvgSpeed  = wvutilsConvertMPSToMPH(wh1080Work.sensorData.windAvgSpeed);
-    wh1080Work.sensorData.windGustSpeed = wvutilsConvertMPSToMPH(wh1080Work.sensorData.windGustSpeed);
-    wh1080Work.sensorData.rain          = wvutilsConvertMMToIN(wh1080Work.sensorData.rain);
+    wh1080Work.sensorData.intemp        = wvutilsConvertCToF( wh1080Work.sensorData.intemp );
+    wh1080Work.sensorData.outtemp       = wvutilsConvertCToF( wh1080Work.sensorData.outtemp );
+    wh1080Work.sensorData.pressure      = wvutilsConvertHPAToINHG( wh1080Work.sensorData.pressure );
+    wh1080Work.sensorData.windAvgSpeed  = wvutilsConvertMPSToMPH( wh1080Work.sensorData.windAvgSpeed );
+    wh1080Work.sensorData.windGustSpeed = wvutilsConvertMPSToMPH( wh1080Work.sensorData.windGustSpeed );
+    wh1080Work.sensorData.rain          = wvutilsConvertMMToIN( wh1080Work.sensorData.rain );
 
     return OK;
 }
 
 
-static void storeLoopPkt (WVIEWD_WORK *work, LOOP_PKT *dest, WH1080_DATA *src)
+static void storeLoopPkt( WVIEWD_WORK* work, LOOP_PKT* dest, WH1080_DATA* src )
 {
     float               tempfloat;
-    WH1080_IF_DATA*     ifWorkData = (WH1080_IF_DATA*)work->stationData;
-    time_t              nowTime = time(NULL);
+    WH1080_IF_DATA*     ifWorkData = ( WH1080_IF_DATA* )work->stationData;
+    time_t              nowTime = time( NULL );
 
     // Clear optional data:
-    stationClearLoopData(work);
+    stationClearLoopData( work );
 
-    if ((10 < src->pressure && src->pressure < 50) &&
-        (-150 < src->outtemp && src->outtemp < 150))
+    if( ( 10 < src->pressure && src->pressure < 50 ) &&
+            ( -150 < src->outtemp && src->outtemp < 150 ) )
     {
         // WH1080 produces station pressure
         dest->stationPressure               = src->pressure;
-    
+
         // Apply calibration here so the computed values reflect it:
         dest->stationPressure *= work->calMPressure;
         dest->stationPressure += work->calCPressure;
-    
+
         // compute sea-level pressure (BP)
-        tempfloat = wvutilsConvertSPToSLP(dest->stationPressure,
-                                          src->outtemp,
-                                          (float)ifWorkData->elevation);
+        tempfloat = wvutilsConvertSPToSLP( dest->stationPressure,
+                                           src->outtemp,
+                                           ( float )ifWorkData->elevation );
         dest->barometer                     = tempfloat;
-    
+
         // calculate altimeter
-        tempfloat = wvutilsConvertSPToAltimeter(dest->stationPressure,
-                                                (float)ifWorkData->elevation);
+        tempfloat = wvutilsConvertSPToAltimeter( dest->stationPressure,
+                    ( float )ifWorkData->elevation );
         dest->altimeter                     = tempfloat;
     }
 
-    if (-150 < src->outtemp && src->outtemp < 150)
+    if( -150 < src->outtemp && src->outtemp < 150 )
     {
         dest->outTemp  = src->outtemp;
     }
 
-    if (0 <= src->outhumidity && src->outhumidity <= 100)
+    if( 0 <= src->outhumidity && src->outhumidity <= 100 )
     {
         tempfloat = src->outhumidity;
         tempfloat += 0.5;
-        dest->outHumidity  = (uint16_t)tempfloat;
+        dest->outHumidity  = ( uint16_t )tempfloat;
     }
 
-    if (0 <= src->windAvgSpeed && src->windAvgSpeed <= 250)
+    if( 0 <= src->windAvgSpeed && src->windAvgSpeed <= 250 )
     {
         tempfloat = src->windAvgSpeed;
         dest->windSpeedF  = tempfloat;
     }
 
-    if (0 <= src->windDir && src->windDir <= 360)
+    if( 0 <= src->windDir && src->windDir <= 360 )
     {
         tempfloat = src->windDir;
         tempfloat += 0.5;
-        dest->windDir        = (uint16_t)tempfloat;
-        dest->windGustDir    = (uint16_t)tempfloat;
+        dest->windDir        = ( uint16_t )tempfloat;
+        dest->windGustDir    = ( uint16_t )tempfloat;
     }
 
-    if (0 <= src->windGustSpeed && src->windGustSpeed <= 250)
+    if( 0 <= src->windGustSpeed && src->windGustSpeed <= 250 )
     {
         tempfloat = src->windGustSpeed;
         dest->windGustF      = tempfloat;
     }
 
-    if (0 <= src->rain)
+    if( 0 <= src->rain )
     {
-        if (!work->runningFlag)
+        if( !work->runningFlag )
         {
             // just starting, so start with whatever the station reports:
             ifWorkData->totalRain = src->rain;
@@ -561,7 +561,7 @@ static void storeLoopPkt (WVIEWD_WORK *work, LOOP_PKT *dest, WH1080_DATA *src)
         else
         {
             // process the rain accumulator
-            if (src->rain - ifWorkData->totalRain >= 0)
+            if( src->rain - ifWorkData->totalRain >= 0 )
             {
                 dest->sampleRain = src->rain - ifWorkData->totalRain;
                 ifWorkData->totalRain = src->rain;
@@ -570,34 +570,34 @@ static void storeLoopPkt (WVIEWD_WORK *work, LOOP_PKT *dest, WH1080_DATA *src)
             {
                 // we had a counter reset...
                 dest->sampleRain = src->rain;
-                dest->sampleRain += (WH1080_RAIN_MAX - ifWorkData->totalRain);
+                dest->sampleRain += ( WH1080_RAIN_MAX - ifWorkData->totalRain );
                 ifWorkData->totalRain = src->rain;
             }
         }
 
-        if (dest->sampleRain > 2)
+        if( dest->sampleRain > 2 )
         {
             // Not possible, filter it out:
             dest->sampleRain = 0;
         }
 
         // Update the rain accumulator:
-        sensorAccumAddSample (ifWorkData->rainRateAccumulator, nowTime, dest->sampleRain);
-        dest->rainRate    = sensorAccumGetTotal (ifWorkData->rainRateAccumulator);
-        dest->rainRate   *= (60/WH1080_RAIN_RATE_PERIOD);
+        sensorAccumAddSample( ifWorkData->rainRateAccumulator, nowTime, dest->sampleRain );
+        dest->rainRate    = sensorAccumGetTotal( ifWorkData->rainRateAccumulator );
+        dest->rainRate   *= ( 60 / WH1080_RAIN_RATE_PERIOD );
     }
     else
     {
         dest->sampleRain = 0;
-        sensorAccumAddSample (ifWorkData->rainRateAccumulator, nowTime, dest->sampleRain);
-        dest->rainRate                      = sensorAccumGetTotal (ifWorkData->rainRateAccumulator);
-        dest->rainRate                      *= (60/WH1080_RAIN_RATE_PERIOD);
+        sensorAccumAddSample( ifWorkData->rainRateAccumulator, nowTime, dest->sampleRain );
+        dest->rainRate                      = sensorAccumGetTotal( ifWorkData->rainRateAccumulator );
+        dest->rainRate                      *= ( 60 / WH1080_RAIN_RATE_PERIOD );
     }
 
     dest->inTemp                        = src->intemp;
     tempfloat = src->inhumidity;
     tempfloat += 0.5;
-    dest->inHumidity                    = (uint16_t)tempfloat;
+    dest->inHumidity                    = ( uint16_t )tempfloat;
 
     return;
 }
@@ -607,116 +607,116 @@ static void storeLoopPkt (WVIEWD_WORK *work, LOOP_PKT *dest, WH1080_DATA *src)
 //////////////////////////////////  A P I  /////////////////////////////////////
 ////////////////////////////////////////////////////////////////////////////////
 
-int wh1080Init (WVIEWD_WORK *work)
+int wh1080Init( WVIEWD_WORK* work )
 {
-    WH1080_IF_DATA*     ifWorkData = (WH1080_IF_DATA*)work->stationData;
+    WH1080_IF_DATA*     ifWorkData = ( WH1080_IF_DATA* )work->stationData;
     fd_set              rfds;
     struct timeval      tv;
     int                 ret;
-    time_t              nowTime = time(NULL) - (WV_SECONDS_IN_HOUR/(60/WH1080_RAIN_RATE_PERIOD));
+    time_t              nowTime = time( NULL ) - ( WV_SECONDS_IN_HOUR / ( 60 / WH1080_RAIN_RATE_PERIOD ) );
     ARCHIVE_PKT         recordStore;
     unsigned char       controlBlock[WH1080_BUFFER_CHUNK];
 
-    memset (&wh1080Work, 0, sizeof(wh1080Work));
+    memset( &wh1080Work, 0, sizeof( wh1080Work ) );
 
     // Create the rain accumulator (WH1080_RAIN_RATE_PERIOD minute age)
     // so we can compute rain rate:
-    ifWorkData->rainRateAccumulator = sensorAccumInit(WH1080_RAIN_RATE_PERIOD);
+    ifWorkData->rainRateAccumulator = sensorAccumInit( WH1080_RAIN_RATE_PERIOD );
 
     // Populate the accumulator with the last WH1080_RAIN_RATE_PERIOD minutes:
-    while ((nowTime = dbsqliteArchiveGetNextRecord(nowTime, &recordStore)) != ERROR)
+    while( ( nowTime = dbsqliteArchiveGetNextRecord( nowTime, &recordStore ) ) != ERROR )
     {
-        sensorAccumAddSample(ifWorkData->rainRateAccumulator,
-                             recordStore.dateTime,
-                             recordStore.value[DATA_INDEX_rain]);
+        sensorAccumAddSample( ifWorkData->rainRateAccumulator,
+                              recordStore.dateTime,
+                              recordStore.value[DATA_INDEX_rain] );
     }
 
-    if ((*(work->medium.usbhidInit))(&work->medium) != OK)
+    if( ( *( work->medium.usbhidInit ) )( &work->medium ) != OK )
     {
         return ERROR;
     }
 
     // Set the station to log data once per minute:
-    while ((!work->exiting) && (readFixedBlock(work, controlBlock) != OK))
+    while( ( !work->exiting ) && ( readFixedBlock( work, controlBlock ) != OK ) )
     {
-        radMsgLog (PRI_HIGH, "WH1080: Initial fixed block read failed");
-        (*(work->medium.usbhidExit))(&work->medium);
-        radUtilsSleep(5000);
-        (*(work->medium.usbhidInit))(&work->medium);
-        radMsgLog (PRI_HIGH, "WH1080: Retrying initial fixed block read");
+        radMsgLog( PRI_HIGH, "WH1080: Initial fixed block read failed" );
+        ( *( work->medium.usbhidExit ) )( &work->medium );
+        radUtilsSleep( 5000 );
+        ( *( work->medium.usbhidInit ) )( &work->medium );
+        radMsgLog( PRI_HIGH, "WH1080: Retrying initial fixed block read" );
     }
 
     // For some reason the WH1080 wants the IF closed between a read and a write:
-    (*(work->medium.usbhidExit))(&work->medium);
-    if (work->exiting)
+    ( *( work->medium.usbhidExit ) )( &work->medium );
+    if( work->exiting )
     {
         return ERROR;
     }
 
     controlBlock[WH1080_SAMPLING_INTERVAL] = 1;
-    (*(work->medium.usbhidInit))(&work->medium);
+    ( *( work->medium.usbhidInit ) )( &work->medium );
 
-    if (writeFixedBlock(work, controlBlock) == ERROR)
+    if( writeFixedBlock( work, controlBlock ) == ERROR )
     {
-        (*(work->medium.usbhidExit))(&work->medium);
+        ( *( work->medium.usbhidExit ) )( &work->medium );
         return ERROR;
     }
 
-    radUtilsSleep(2000);
+    radUtilsSleep( 2000 );
 
-    (*(work->medium.usbhidExit))(&work->medium);
+    ( *( work->medium.usbhidExit ) )( &work->medium );
 
-    radUtilsSleep(1000);
+    radUtilsSleep( 1000 );
 
     wh1080Work.lastRecord = -1;
 
     // populate the LOOP structure:
-    radMsgLog (PRI_HIGH, "Waiting for the next weather record to be ready "
-                         "in the console to populate initial wview sensor readings "
-                         "(this could take some time);");
-    radMsgLog (PRI_HIGH, "While waiting be sure you are receiving all sensors on the console;");
-    radMsgLog (PRI_HIGH, "if not, you may need to relocate the sensors or the console.");
-    while ((!work->exiting) && (readStationData(work) != OK))
+    radMsgLog( PRI_HIGH, "Waiting for the next weather record to be ready "
+               "in the console to populate initial wview sensor readings "
+               "(this could take some time);" );
+    radMsgLog( PRI_HIGH, "While waiting be sure you are receiving all sensors on the console;" );
+    radMsgLog( PRI_HIGH, "if not, you may need to relocate the sensors or the console." );
+    while( ( !work->exiting ) && ( readStationData( work ) != OK ) )
     {
-        radUtilsSleep(1000);
+        radUtilsSleep( 1000 );
     }
-    if (work->exiting)
+    if( work->exiting )
     {
         return ERROR;
     }
 
     ifWorkData->wh1080Readings = wh1080Work.sensorData;
-    storeLoopPkt (work, &work->loopPkt, &ifWorkData->wh1080Readings);
+    storeLoopPkt( work, &work->loopPkt, &ifWorkData->wh1080Readings );
 
     // we must indicate successful completion here -
     // even though we are synchronous, the daemon wants to see this event:
-    radProcessEventsSend (NULL, STATION_INIT_COMPLETE_EVENT, 0);
+    radProcessEventsSend( NULL, STATION_INIT_COMPLETE_EVENT, 0 );
 
     return OK;
 }
 
-void wh1080Exit (WVIEWD_WORK *work)
+void wh1080Exit( WVIEWD_WORK* work )
 {
     return;
 }
 
-void wh1080ReadData (WVIEWD_WORK *work)
+void wh1080ReadData( WVIEWD_WORK* work )
 {
     return;
 }
 
-void wh1080GetReadings (WVIEWD_WORK *work)
+void wh1080GetReadings( WVIEWD_WORK* work )
 {
-    WH1080_IF_DATA*  ifWorkData = (WH1080_IF_DATA*)work->stationData;
+    WH1080_IF_DATA*  ifWorkData = ( WH1080_IF_DATA* )work->stationData;
 
-    if (readStationData(work) == OK)
+    if( readStationData( work ) == OK )
     {
         // populate the LOOP structure:
         ifWorkData->wh1080Readings = wh1080Work.sensorData;
-        storeLoopPkt (work, &work->loopPkt, &ifWorkData->wh1080Readings);
+        storeLoopPkt( work, &work->loopPkt, &ifWorkData->wh1080Readings );
 
         // indicate the LOOP packet is done
-        radProcessEventsSend (NULL, STATION_LOOP_COMPLETE_EVENT, 0);
+        radProcessEventsSend( NULL, STATION_LOOP_COMPLETE_EVENT, 0 );
     }
 }
 
