@@ -1,32 +1,32 @@
 /*---------------------------------------------------------------------------
- 
+
   FILENAME:
         usbhid.c
- 
+
   PURPOSE:
         Provide the weather station USB HID medium utilities.
- 
+
   REVISION HISTORY:
         Date            Engineer        Revision        Remarks
         02/15/2011      M.S. Teel       0               Original
- 
+
   NOTES:
         wview medium-specific routines to be supplied:
-        
+
         usbhidMediumInit       - sets up function pointers and work area
         usbhidInit             - initialize
         usbhidExit             - exit
         usbhidRead             - blocking read until specified bytes are read
         usbhidWrite            - write on medium
-        
+
         See daemon.h for details of the WVIEW_MEDIUM structure.
- 
+
   LICENSE:
         Copyright (c) 2011, Mark S. Teel (mark@teel.ws)
-  
-        This source code is released for free distribution under the terms 
+
+        This source code is released for free distribution under the terms
         of the GNU General Public License.
-  
+
 ----------------------------------------------------------------------------*/
 
 /*  ... System include files
@@ -65,93 +65,86 @@
 /*  ... local memory
 */
 static MEDIUM_USBHID    mediumUSB;
-static void usbhidExit (WVIEW_MEDIUM *med);
+static void usbhidExit( WVIEW_MEDIUM* med );
 
 //////////////////////////////////////////////////////////////////////////////
 //  ... medium callback functions
 //////////////////////////////////////////////////////////////////////////////
 
-static int usbhidInit (WVIEW_MEDIUM *medium)
+static int usbhidInit( WVIEW_MEDIUM* medium )
 {
-    MEDIUM_USBHID   *usbhidWork = (MEDIUM_USBHID *)medium->workData;
+    MEDIUM_USBHID*   usbhidWork = ( MEDIUM_USBHID* )medium->workData;
 
     // Open the HID device:
-    medium->hidDevice = hid_open(usbhidWork->vendorId, usbhidWork->productId);
-    if (medium->hidDevice == NULL)
+    medium->hidDevice = hid_open( usbhidWork->vendorId, usbhidWork->productId );
+    if( medium->hidDevice == NULL )
     {
-        radMsgLog (PRI_HIGH, "USBHID: hid_open failed!");
+        radMsgLog( PRI_HIGH, "USBHID: hid_open failed!" );
         return ERROR;
     }
 
     // Set to non-blocking so we can do timed read exact:
-    if (hid_set_nonblocking(medium->hidDevice, !usbhidWork->blocking) != 0)
+    if( hid_set_nonblocking( medium->hidDevice, !usbhidWork->blocking ) != 0 )
     {
-        radMsgLog (PRI_HIGH, "USBHID: hid_set_nonblocking failed!");
-        usbhidExit(medium);
+        radMsgLog( PRI_HIGH, "USBHID: hid_set_nonblocking failed!" );
+        usbhidExit( medium );
         return ERROR;
     }
 
     return OK;
 }
 
-static void usbhidExit (WVIEW_MEDIUM *med)
+static void usbhidExit( WVIEW_MEDIUM* med )
 {
-    if (med->hidDevice != NULL)
-        hid_close(med->hidDevice);
-	med->hidDevice = NULL;
+    if( med->hidDevice != NULL )
+        hid_close( med->hidDevice );
+    med->hidDevice = NULL;
 
     return;
 }
 
 static int usbhidRead
 (
-    struct _wview_medium    *medium,
-    void                    *buffer,
-    int                     length, 
+    struct _wview_medium*    medium,
+    void*                    buffer,
+    int                     length,
     int                     msTimeout
 )
 {
     int                     rval, cumTime = 0, index = 0;
     uint64_t                readTime;
-    uint8_t                 *ptr = (uint8_t *)buffer;
-    MEDIUM_USBHID           *usbhidWork = (MEDIUM_USBHID *)medium->workData;
+    uint8_t*                 ptr = ( uint8_t* )buffer;
+    MEDIUM_USBHID*           usbhidWork = ( MEDIUM_USBHID* )medium->workData;
 
-    while (index < length)
+    while( index < length )
     {
         // Bail out if non-blocking IO and timeout has expired.
-        if (!usbhidWork->blocking && cumTime >= msTimeout)
+        if( !usbhidWork->blocking && cumTime >= msTimeout )
         {
             return index;
         }
 
-        readTime = radTimeGetMSSinceEpoch ();
-        rval = hid_read(medium->hidDevice, &ptr[index], length - index);
-        if (rval < 0)
+        readTime = radTimeGetMSSinceEpoch();
+        rval = hid_read_timeout( medium->hidDevice, &ptr[index], length - index, msTimeout - cumTime );
+        if( rval < 0 )
         {
-            if (errno != EINTR && errno != EAGAIN)
+            if( errno != EINTR && errno != EAGAIN )
             {
                 return ERROR;
             }
         }
         else
         {
-            if (rval > 0 && usbhidWork->debug)
+            if( rval > 0 && usbhidWork->debug )
             {
-                radMsgLog (PRI_STATUS, "usbhidRead:");
-                radMsgLogData(&ptr[index], rval);
+                radMsgLog( PRI_STATUS, "usbhidRead:" );
+                radMsgLogData( &ptr[index], rval );
             }
             index += rval;
         }
 
-        readTime = radTimeGetMSSinceEpoch () - readTime;
-        cumTime += (int)readTime;
-        if (!usbhidWork->blocking && index < length && cumTime < msTimeout)
-        {
-            readTime = radTimeGetMSSinceEpoch ();
-            radUtilsSleep (9);
-            readTime = radTimeGetMSSinceEpoch () - readTime;
-            cumTime += (int)readTime;
-        }
+        readTime = radTimeGetMSSinceEpoch() - readTime;
+        cumTime += ( int )readTime;
     }
 
     return index;
@@ -159,62 +152,62 @@ static int usbhidRead
 
 static int usbhidReadSpecial
 (
-    struct _wview_medium    *medium,
-    void                    *buffer,
-    int                     length, 
+    struct _wview_medium*    medium,
+    void*                    buffer,
+    int                     length,
     int                     msTimeout
 )
 {
     int                     rval, cumTime = 0, index = 0, i, blockLen;
     uint64_t                readTime;
-    uint8_t                 *ptr = (uint8_t *)buffer;
+    uint8_t*                 ptr = ( uint8_t* )buffer;
     uint8_t                 readBuf[8];
-    MEDIUM_USBHID           *usbhidWork = (MEDIUM_USBHID *)medium->workData;
+    MEDIUM_USBHID*           usbhidWork = ( MEDIUM_USBHID* )medium->workData;
 
-    while (index < length && cumTime < msTimeout)
+    while( index < length && cumTime < msTimeout )
     {
-        readTime = radTimeGetMSSinceEpoch ();
+        readTime = radTimeGetMSSinceEpoch();
 
         // Read in 8-byte blocks:
-        rval = hid_read(medium->hidDevice, &readBuf[0], 8);
-        if (rval < 0)
+        rval = hid_read( medium->hidDevice, &readBuf[0], 8 );
+        if( rval < 0 )
         {
-            if (errno != EINTR && errno != EAGAIN)
+            if( errno != EINTR && errno != EAGAIN )
             {
                 return ERROR;
             }
         }
-        else if (rval > 0)
+        else if( rval > 0 )
         {
             // Now we should have an 8-byte block of data:
             // Process the first byte as a length field:
-            blockLen = (int)readBuf[0];
-            if ((blockLen > 7) || (blockLen > (rval-1)))
+            blockLen = ( int )readBuf[0];
+            if( ( blockLen > 7 ) || ( blockLen > ( rval - 1 ) ) )
             {
                 // Impossible:
                 return ERROR;
             }
-    
+
             // Copy the length given:
-            memcpy(&ptr[index], &readBuf[1], MIN(blockLen,(length-index)));
-            index += MIN(blockLen,(length-index));
+            memcpy( &ptr[index], &readBuf[1], MIN( blockLen, ( length - index ) ) );
+            index += MIN( blockLen, ( length - index ) );
         }
 
-        readTime = radTimeGetMSSinceEpoch () - readTime;
-        cumTime += (int)readTime;
-        if ((index < length) && (cumTime < msTimeout))
+        readTime = radTimeGetMSSinceEpoch() - readTime;
+        cumTime += ( int )readTime;
+        if( ( index < length ) && ( cumTime < msTimeout ) )
         {
-            readTime = radTimeGetMSSinceEpoch ();
-            radUtilsSleep (9);
-            readTime = radTimeGetMSSinceEpoch () - readTime;
-            cumTime += (int)readTime;
+            readTime = radTimeGetMSSinceEpoch();
+            radUtilsSleep( 9 );
+            readTime = radTimeGetMSSinceEpoch() - readTime;
+            cumTime += ( int )readTime;
         }
     }
 
-    if (index > 0 && usbhidWork->debug)
+    if( index > 0 && usbhidWork->debug )
     {
-        radMsgLog (PRI_STATUS, "usbhidReadSpecial:");
-        radMsgLogData(&ptr[0], index);
+        radMsgLog( PRI_STATUS, "usbhidReadSpecial:" );
+        radMsgLogData( &ptr[0], index );
     }
 
     return index;
@@ -222,35 +215,35 @@ static int usbhidReadSpecial
 
 static int usbhidWrite
 (
-    struct _wview_medium    *medium,
-    void                    *buffer,
+    struct _wview_medium*    medium,
+    void*                    buffer,
     int                     length
 )
 {
     int                     retVal, index = 0;
-    MEDIUM_USBHID           *usbhidWork = (MEDIUM_USBHID *)medium->workData;
-    uint8_t*                sendPtr = (uint8_t*)buffer;
+    MEDIUM_USBHID*           usbhidWork = ( MEDIUM_USBHID* )medium->workData;
+    uint8_t*                sendPtr = ( uint8_t* )buffer;
 
     // Write in 8-byte chunks:
-    while (index < length)
+    while( index < length )
     {
-        retVal = hid_write(medium->hidDevice, &sendPtr[index], 8);
-        if (retVal != 8)
+        retVal = hid_write( medium->hidDevice, &sendPtr[index], 8 );
+        if( retVal != 8 )
         {
-            if (retVal == -1)
+            if( retVal == -1 )
             {
-                if (usbhidWork->debug)
+                if( usbhidWork->debug )
                 {
-                    radMsgLog (PRI_HIGH, "USBHID: hid_write failed");
+                    radMsgLog( PRI_HIGH, "USBHID: hid_write failed" );
                 }
                 return ERROR;
             }
             else
             {
-                if (usbhidWork->debug)
+                if( usbhidWork->debug )
                 {
-                    radMsgLog (PRI_HIGH, "USBHID: hid_write is SHORT: %d of %d",
-                               retVal, length);
+                    radMsgLog( PRI_HIGH, "USBHID: hid_write is SHORT: %d of %d",
+                               retVal, length );
                 }
                 return retVal;
             }
@@ -259,10 +252,10 @@ static int usbhidWrite
         index += 8;
     }
 
-    if (usbhidWork->debug)
+    if( usbhidWork->debug )
     {
-        radMsgLog (PRI_STATUS, "usbhidWrite:");
-        radMsgLogData(buffer, length);
+        radMsgLog( PRI_STATUS, "usbhidWrite:" );
+        radMsgLogData( buffer, length );
     }
 
     return length;
@@ -273,17 +266,17 @@ static int usbhidWrite
 
 int usbhidMediumInit
 (
-    WVIEW_MEDIUM    *medium,
+    WVIEW_MEDIUM*    medium,
     uint16_t        vendor_id,
     uint16_t        product_id,
     int             enableDebug,
     int             blocking
 )
 {
-    MEDIUM_USBHID   *work = &mediumUSB;
+    MEDIUM_USBHID*   work = &mediumUSB;
 
-    memset (medium, 0, sizeof (*medium));
-    memset (work, 0, sizeof (*work));
+    memset( medium, 0, sizeof( *medium ) );
+    memset( work, 0, sizeof( *work ) );
 
     work->vendorId  = vendor_id;
     work->productId = product_id;
@@ -293,7 +286,7 @@ int usbhidMediumInit
     medium->type = MEDIUM_TYPE_USBHID;
 
     // set our workData pointer for later use
-    medium->workData = (void *)work;
+    medium->workData = ( void* )work;
 
     medium->usbhidInit          = usbhidInit;
     medium->usbhidExit          = usbhidExit;
